/*******************************************************************************
 * Copyright (c) 2000, 2015 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jface.resource;

import org.eclipse.swt.graphics.ImageData;

/**
 * The image descriptor for a missing image.
 * <p>
 * Use <code>MissingImageDescriptor.getInstance</code> to
 * access the singleton instance maintained in an
 * internal state variable.
 * </p>
 */
class MissingImageDescriptor extends ImageDescriptor {
	private static MissingImageDescriptor instance;

	/**
	 * Constructs a new missing image descriptor.
	 */
	private MissingImageDescriptor() {
		super();
	}

	@Override
	public ImageData getImageData() {
		return DEFAULT_IMAGE_DATA;
	}

	/**
	 * Returns the shared missing image descriptor instance.
	 *
	 * @return the image descriptor for a missing image
	 */
	static MissingImageDescriptor getInstance() {
		if (instance == null) {
			instance = new MissingImageDescriptor();
		}
		return instance;
	}
}
